#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   haskell-gi-base
version:                0.26.9
visibility:             public
id:                     haskell-gi-base-0.26.9-9dGlnSJnubc2h9MiqHeprA
key:                    haskell-gi-base-0.26.9-9dGlnSJnubc2h9MiqHeprA
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria (inaki@blueleaf.cc)
author:
    Will Thompson,
    Iñaki García Etxebarria,
    Jonas Platte

stability:              Experimental
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:               Foundation for libraries generated by haskell-gi
description:            Foundation for libraries generated by haskell-gi
category:               Development
abi:                    110d06de00e97012fa4e2bb4624f6346
exposed:                True
exposed-modules:
    Data.GI.Base Data.GI.Base.Attributes Data.GI.Base.BasicConversions
    Data.GI.Base.BasicTypes Data.GI.Base.CallStack
    Data.GI.Base.Constructible Data.GI.Base.DynVal Data.GI.Base.GArray
    Data.GI.Base.GClosure Data.GI.Base.GError Data.GI.Base.GHashTable
    Data.GI.Base.GObject Data.GI.Base.GParamSpec Data.GI.Base.GQuark
    Data.GI.Base.GType Data.GI.Base.GValue Data.GI.Base.GVariant
    Data.GI.Base.Internal.CTypes Data.GI.Base.Internal.PathFieldAccess
    Data.GI.Base.ManagedPtr Data.GI.Base.Overloading
    Data.GI.Base.Properties Data.GI.Base.ShortPrelude
    Data.GI.Base.Signals Data.GI.Base.Utils

import-dirs:            /usr/lib/ghc-9.6.6/site-local/haskell-gi-base-0.26.9
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-gi-base-0.26.9 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-gi-base-0.26.9 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-base
hs-libraries:           HShaskell-gi-base-0.26.9-9dGlnSJnubc2h9MiqHeprA
extra-libraries:        gobject-2.0 glib-2.0
extra-libraries-static:
    gobject-2.0 ffi glib-2.0 atomic m sysprof-capture-4 pcre2-8 pthread

include-dirs:
    /usr/include /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/sysprof-6

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    optics-core-0.4.1.1-3uSkdT24fvM6dyJIU7nYms text-2.0.2

haddock-interfaces:     /usr/share/doc/haskell-gi-base/html/haskell-gi-base.haddock
haddock-html:           /usr/share/doc/haskell-gi-base/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

